<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Capabilities Documentation

- **[adding-new-capabilities.md](adding-new-capabilities.md)** — adding reminder capabilities, creating new capability types, debugging capability registration
- **[adding-reviews.md](adding-reviews.md)** — adding review capabilities, creating code review definitions, understanding ReviewCapability pattern
- **[adding-skills.md](adding-skills.md)** — adding skill capabilities, creating new skills for external projects, understanding SkillCapability pattern
- **[adding-workflows.md](adding-workflows.md)** — adding workflow capabilities, creating GitHub Actions workflow capabilities, understanding workflow capability pattern
- **[folder-structure.md](folder-structure.md)** — adding new capability implementations, deciding where to place capability files, understanding capability organization
